@@ -217,6 +217,24 @@ class WebSearch :
         self.__data['ods'] = (self.query, result)
         return result
 
+    @property
+    def odp(self):
+        '''
+            Fonction pour recuperer que les documents odp.
+        '''
+         #  On vérifie que les résultats ne sont pas déjà enregistrés.
+        if self.__data.get('odp'):
+            if self.__data['odp'][0] == self.query:
+                return self.__data['odp'][1]
+        tmp = self.query
+        self.query = 'filetype:odp ' + self.query
+        result = self.__verif_content(self.pages, "application/vnd.oasis.opendocument.presentation")
+        self.query = tmp
+         #  Sauvegarde des resultats pour optimiser la prochaine même appel.
+        self.__data['odp'] = (self.query, result)
+        return result
+
+
     @property
     def kml(self):
         '''
@@ -235,7 +253,7 @@ class WebSearch :
         self.__data['kml'] = (self.query, result)
         return result
 
-    def custom_search(self, extension='pdf', mimetype='application/pdf'):
+    def custom(self, extension='pdf', mimetype='application/pdf'):
         '''
             Fonction pour recuperer des fichiers en fonction
             de l'extension voulu et des type de mime que ce dernier utilise
@@ -256,3 +274,5 @@ class WebSearch :
         self.__data[extension] = (self.query, result)
         return result
 
+    def custom_search(self, *args, **kwargs):
+        raise Exception("`custom_search` is deprecated since v1.0.4, use `custom` instead")
